@@ -1,5 +1,4 @@
 from django.conf import settings
-from django.utils.module_loading import import_string
 
 
 LOGGING_USER_MODEL = getattr(settings, 'LOGGING_USER_MODEL', None) or getattr(settings, 'AUTH_USER_MODEL', None)
@@ -26,11 +25,9 @@ MIDDLEWARES = settings.MIDDLEWARE
 LOGGING_DATABASE = getattr(settings, 'LOGGING_DATABASE', 'default')
 
 JSON_ENCODER_PATH = getattr(settings, 'LOGGING_JSON_ENCODER', 'models_logging.utils.ExtendedEncoder')
-JSON_ENCODER = import_string(JSON_ENCODER_PATH)
 
 GET_CHANGE_EXTRAS_PATH = getattr(
     settings,
     'LOGGING_GET_CHANGE_EXTRAS_FUNC',
-    'models_logging.utils.get_change_extras'
+    'models_logging.helpers.get_change_extras'
 )
-GET_CHANGE_EXTRAS_FUNC = import_string(GET_CHANGE_EXTRAS_PATH)
